@@ -1,8 +1,8 @@
 #!/bin/sh
 # -*- mode: shell-script -*-
 #
-# Copyright (C) 2004-2017 Alan W. Irwin
-# Copyright (C) 2004  Rafael Laboissiere
+# Copyright (C) 2004-2018 Alan W. Irwin
+# Copyright (C) 2004 Rafael Laboissiere
 #
 # This file is part of PLplot.
 #
@@ -32,19 +32,19 @@
 # (e.g., gv for postscript files and kview or a browser for png, gif,
 # or jpeg files on Linux systems) to make sure they display properly.
 
-version=5.13.0
+version=5.15.0
 
-EXAMPLES_DIR=${EXAMPLES_DIR:-.}
-SRC_EXAMPLES_DIR=${SRC_EXAMPLES_DIR:-.}
+EXAMPLES_PREFIX=${EXAMPLES_PREFIX:-.}
+SRC_EXAMPLES_PREFIX=${SRC_EXAMPLES_PREFIX:-.}
 OUTPUT_DIR=${OUTPUT_DIR:-.}
 device=${DEVICE:-psc}
 # Check if we are in the build tree
-if [ "`pwd`/.." -ef "/usr/obj/ports/plplot-5.13.0/build-i386" ] ; then
+if [ "`pwd`/.." -ef "/usr/ports/pobj/plplot-5.15.0/build-powerpc64" ] ; then
   BUILD_TREE="YES"
 else
   BUILD_TREE="NO"
 fi
-export EXAMPLES_DIR SRC_EXAMPLES_DIR OUTPUT_DIR device DEBUG_CMD BUILD_TREE
+export EXAMPLES_PREFIX SRC_EXAMPLES_PREFIX OUTPUT_DIR device DEBUG_CMD BUILD_TREE
 
 usage()
 {
@@ -53,13 +53,13 @@ Usage: plplot-test.sh [OPTIONS]
 
 Options:
    [--device=DEVICE] (DEVICE = any cmake-enabled device.  psc is the default)
-   [--front-end=FE]  (FE = one of c, cxx, fortran java, octave, python, tcl, pdl, ada, ocaml, lua, d or plrender)
+   [--front-end=FE]  (FE = one of c, cxx, fortran java, octave, python, tcl, ada, ocaml, lua, d or plrender)
                      If this option is not specified, then all front-ends will
                      be tested.  More than one front-end may be given, like
                      this --front-end="c cxx"
-   [--examples-dir=/path/to/examples/dir]
+   [--examples-prefix=/path/to/examples/dir]
                      Specify path to the examples directory.  Defaults to "."
-   [--src-examples-dir=/path/to/src/examples/dir]
+   [--src-examples-prefix=/path/to/src/examples/dir]
                      Specify path to the src examples directory.  Defaults to "."
    [--output-dir=/path/to/output/dir]
                      Specify location where the resulting files are stored.
@@ -74,12 +74,12 @@ Options:
    [--help]
 
 Environment variables:
-   DEVICE, FRONT_END, EXAMPLES_DIR, SRC_EXAMPLES_DIR, and OUTPUT_DIR can be
+   DEVICE, FRONT_END, EXAMPLES_PREFIX, SRC_EXAMPLES_PREFIX, and OUTPUT_DIR can be
    used to specify the devices, front-ends, the examples directory, the
    source examples directory (used for the special case of build-tree checks
    when that tree is separated from the source tree), and output directory.
    These environment variables are overridden by the options --device,
-   --front-end, --examples-dir, --src-examples-dir, and --output-dir.
+   --front-end, --examples-prefix, --src-examples-prefix, and --output-dir.
 '
    exit $1
 }
@@ -126,7 +126,6 @@ while test $# -gt 0; do
              -o $i = "octave" \
              -o $i = "python" \
              -o $i = "tcl"    \
-             -o $i = "pdl"    \
              -o $i = "ada"    \
              -o $i = "ocaml"    \
              -o $i = "lua"    \
@@ -136,11 +135,11 @@ while test $# -gt 0; do
            || usage 0 1>&2
          done
 	 ;;
-      --examples-dir=*)
-         EXAMPLES_DIR=$optarg
+      --examples-prefix=*)
+         EXAMPLES_PREFIX=$optarg
          ;;
-      --src-examples-dir=*)
-         SRC_EXAMPLES_DIR=$optarg
+      --src-examples-prefix=*)
+         SRC_EXAMPLES_PREFIX=$optarg
          ;;
       --output-dir=*)
          OUTPUT_DIR=$optarg
@@ -161,13 +160,13 @@ while test $# -gt 0; do
    shift
 done
 
-# This script is only designed to work when EXAMPLES_DIR is a directory
+# This script is only designed to work when EXAMPLES_PREFIX is a directory
 # with a subdirectory called "c".  Check whether this conditions is true.
 
-if [ ! -d "$EXAMPLES_DIR"/c ] ; then
+if [ ! -d "$EXAMPLES_PREFIX"/c ] ; then
 echo '
-This script is only designed to work when the EXAMPLES_DIR environment
-variable (overridden by option --examples-dir) is a directory with a
+This script is only designed to work when the EXAMPLES_PREFIX environment
+variable (overridden by option --examples-prefix) is a directory with a
 subdirectory called "c".  This condition has been violated.
 '
 exit 1
@@ -217,7 +216,7 @@ script with DEVICE='"$device"'.
 
     status=0
     if [ "$interactive" = "on" ] ; then
-	export cdir="$EXAMPLES_DIR"/c
+	export cdir="$EXAMPLES_PREFIX"/c
 	echo "Testing subset of C examples for device $device"
 	script="$scripts_dir"/test_c_interactive.sh
     else
@@ -226,14 +225,14 @@ script with DEVICE='"$device"'.
 	export octave=
         if [ "$BUILD_TREE" = "YES" ] ; then
 	    export octavedir=\
-"$SRC_EXAMPLES_DIR"/../bindings/octave/PLplot:\
-"$SRC_EXAMPLES_DIR"/../bindings/octave/PLplot/support:\
-"$SRC_EXAMPLES_DIR"/../bindings/octave/misc:\
-"$SRC_EXAMPLES_DIR"/octave:\
-"$EXAMPLES_DIR"/../bindings/octave:\
-"$EXAMPLES_DIR"/../bindings/octave/PLplot
+"$SRC_EXAMPLES_PREFIX"/../bindings/octave/PLplot:\
+"$SRC_EXAMPLES_PREFIX"/../bindings/octave/PLplot/support:\
+"$SRC_EXAMPLES_PREFIX"/../bindings/octave/misc:\
+"$SRC_EXAMPLES_PREFIX"/octave:\
+"$EXAMPLES_PREFIX"/../bindings/octave:\
+"$EXAMPLES_PREFIX"/../bindings/octave/PLplot
             if [ "OFF" = "ON" ] ; then
-		octavedir=$octavedir:"$EXAMPLES_DIR"/../dll
+		octavedir=$octavedir:"$EXAMPLES_PREFIX"/../dll
 	    fi
         else
             export octavedir=\
@@ -241,7 +240,7 @@ script with DEVICE='"$device"'.
 ""/support:\
 "":\
 "":\
-"$SRC_EXAMPLES_DIR"/octave
+"$SRC_EXAMPLES_PREFIX"/octave
             if [ "OFF" = "ON" ] ; then
 		octavedir=$octavedir:"/usr/local/bin"
 	    fi
@@ -254,35 +253,35 @@ script with DEVICE='"$device"'.
     exit $status
 fi
 
+if [ "$BUILD_TREE" = "YES" ] ; then
+    TREE_EXAMPLES_PREFIX="$EXAMPLES_PREFIX"
+else
+    TREE_EXAMPLES_PREFIX="$SRC_EXAMPLES_PREFIX"
+fi
+
 # These variables set by default assuming you are going to run this
 # script from the installed demos directory $prefix/lib/plplot$version/examples.
-cdir="$EXAMPLES_DIR"/c$VC_CTEST_DIRECTORY
-cxxdir="$EXAMPLES_DIR"/c++$VC_CTEST_DIRECTORY
-if [ "OFF" = "ON" ] ; then
-    fortrandir="$EXAMPLES_DIR"/old_fortran
-else
-    fortrandir="$EXAMPLES_DIR"/fortran
-fi
-pythondir="$SRC_EXAMPLES_DIR"/python
-tclexamplesdir="$EXAMPLES_DIR"/tcl
-tcldir="$SRC_EXAMPLES_DIR"/tcl
-perldir="$SRC_EXAMPLES_DIR"/perl
-javadir="$EXAMPLES_DIR"/java
-adadir="$EXAMPLES_DIR"/ada
-ocamldir="$EXAMPLES_DIR"/ocaml
-luadir="$SRC_EXAMPLES_DIR"/lua
-ddir="$EXAMPLES_DIR"/d
+cdir="$EXAMPLES_PREFIX"/c$VC_CTEST_DIRECTORY
+cxxdir="$EXAMPLES_PREFIX"/c++$VC_CTEST_DIRECTORY
+fortrandir="$EXAMPLES_PREFIX"/fortran
+pythondir="$TREE_EXAMPLES_PREFIX"/python
+tcldir="$EXAMPLES_PREFIX"/tcl
+javadir="$EXAMPLES_PREFIX"/java
+adadir="$EXAMPLES_PREFIX"/ada
+ocamldir="$EXAMPLES_PREFIX"/ocaml
+luadir="$TREE_EXAMPLES_PREFIX"/lua
+ddir="$EXAMPLES_PREFIX"/d
 octave=
 if [ "$BUILD_TREE" = "YES" ] ; then
     octavedir=\
-"$SRC_EXAMPLES_DIR"/../bindings/octave/PLplot:\
-"$SRC_EXAMPLES_DIR"/../bindings/octave/PLplot/support:\
-"$SRC_EXAMPLES_DIR"/../bindings/octave/misc:\
-"$SRC_EXAMPLES_DIR"/octave:\
-"$EXAMPLES_DIR"/../bindings/octave:\
-"$EXAMPLES_DIR"/../bindings/octave/PLplot
+"$SRC_EXAMPLES_PREFIX"/../bindings/octave/PLplot:\
+"$SRC_EXAMPLES_PREFIX"/../bindings/octave/PLplot/support:\
+"$SRC_EXAMPLES_PREFIX"/../bindings/octave/misc:\
+"$SRC_EXAMPLES_PREFIX"/octave:\
+"$EXAMPLES_PREFIX"/../bindings/octave:\
+"$EXAMPLES_PREFIX"/../bindings/octave/PLplot
     if [ "OFF" = "ON" ] ; then
-	octavedir=$octavedir:"$EXAMPLES_DIR"/../dll
+	octavedir=$octavedir:"$EXAMPLES_PREFIX"/../dll
     fi
 else
     export octavedir=\
@@ -290,12 +289,12 @@ else
 ""/support:\
 "":\
 "":\
-"$SRC_EXAMPLES_DIR"/octave
+"$SRC_EXAMPLES_PREFIX"/octave
     if [ "OFF" = "ON" ] ; then
 	octavedir=$octavedir:"/usr/local/bin"
     fi
 fi
-export cdir cxxdir fortrandir pythondir javadir octave octavedir tcldir perldir adadir ocamldir luadir ddir
+export cdir cxxdir fortrandir pythondir javadir octave octavedir tcldir adadir ocamldir luadir ddir
 
 fe=""
 
@@ -327,13 +326,11 @@ PLD_plmeta=OFF
 PLD_png=OFF
 PLD_pngcairo=ON
 PLD_ps=ON
-# special case
 PLD_psc=ON
 PLD_pscairo=ON
 PLD_epscairo=ON
 PLD_pstex=OFF
 PLD_psttf=OFF
-# special case
 PLD_psttfc=OFF
 PLD_svg=ON
 PLD_svgcairo=ON
@@ -394,7 +391,6 @@ if [ -z "$FRONT_END" ] ; then
    test "OFF" = "ON" && FRONT_END="$FRONT_END octave"
    test "OFF" = "ON" && FRONT_END="$FRONT_END python"
    test "OFF" = "ON"    && FRONT_END="$FRONT_END tcl"
-   test "OFF" = "ON"    && FRONT_END="$FRONT_END pdl"
    test "OFF" = "ON"    && FRONT_END="$FRONT_END ada"
    test "OFF" = "ON"  && FRONT_END="$FRONT_END ocaml"
    test "OFF" = "ON"  && FRONT_END="$FRONT_END lua"
