@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/usr/local/bin/bash
 # Test suite for c examples.
 #
 # Copyright (C) 2004  Alan W. Irwin
@@ -37,22 +37,22 @@ for index in 00 01 02 03 04 05 06 07 08 09 10 11 12 13 15 16 18 19 20 \
     if [ "$index" = "14" ] ; then
 	echo "${OUTPUT_DIR}"/x${index}a${lang}%n.$dsuffix | \
 	$DEBUG_CMD "$cdir"/x${index}${lang} -dev $device -o "${OUTPUT_DIR}"/x${index}${lang}%n.$dsuffix \
-	    $options 2> test.error >| "${OUTPUT_DIR}"/x${index}${lang}_${dsuffix}.txt
+	    $options 2> c_${device}_test.error >| "${OUTPUT_DIR}"/x${index}${lang}_${dsuffix}.txt
     # Look for any status codes (segfaults, plexit) from the examples themselves.
 	status_code=$?
     else
 	$DEBUG_CMD "$cdir"/x${index}${lang} -dev $device -o "${OUTPUT_DIR}"/x${index}${lang}%n.$dsuffix \
-	    $options 2> test.error >| "${OUTPUT_DIR}"/x${index}${lang}_${dsuffix}.txt
+	    $options 2> c_${device}_test.error >| "${OUTPUT_DIR}"/x${index}${lang}_${dsuffix}.txt
     # Look for any status codes (segfaults, plexit) from the examples themselves.
 	status_code=$?
     fi
-    cat test.error
+    cat c_${device}_test.error
     if [ "$status_code" -ne 0 ] ; then
 	exit $status_code
     fi
   # Look for any PLPLOT ERROR messages from plwarn that do not result in an
   # exit code.
-    is_error=`grep -l 'PLPLOT ERROR' test.error`
+    is_error=`grep -l 'PLPLOT ERROR' c_${device}_test.error`
     if [ -n "$is_error" ] ; then
 	exit 1
     fi
